@@ -22,18 +22,8 @@
 const Lang = imports.lang;
 const Mainloop = imports.mainloop;
 const Signals = imports.signals;
-const Gettext = imports.gettext;
 const _ = imports.gettext.gettext;
 
-// Import versions go here
-imports.gi.versions.GdPrivate = '1.0';
-imports.gi.versions.Gd = '1.0';
-imports.gi.versions.Tracker = '1.0';
-imports.gi.versions.TrackerControl = '1.0';
-imports.gi.versions.EvinceDocument = '3.0';
-imports.gi.versions.Goa = '1.0';
-imports.gi.versions.WebKit2 = '4.0';
-
 const EvDoc = imports.gi.EvinceDocument;
 const GdPrivate = imports.gi.GdPrivate;
 const Gdk = imports.gi.Gdk;
@@ -53,7 +43,6 @@ const MainToolbar = imports.mainToolbar;
 const Manager = imports.manager;
 const Miners = imports.miners;
 const Notifications = imports.notifications;
-const Path = imports.path;
 const Properties = imports.properties;
 const Query = imports.query;
 const Search = imports.search;
@@ -120,15 +109,11 @@ const Application = new Lang.Class({
 
         this.isBooks = isBooks;
 
-        Gettext.bindtextdomain('gnome-documents', Path.LOCALE_DIR);
-        Gettext.textdomain('gnome-documents');
         let appid;
         if (!this.isBooks) {
-            GLib.set_prgname('gnome-documents');
             GLib.set_application_name(_("Documents"));
             appid = 'org.gnome.Documents';
         } else {
-            GLib.set_prgname('gnome-books');
             GLib.set_application_name(_("Books"));
             appid = 'org.gnome.Books';
         }
@@ -147,7 +132,7 @@ const Application = new Lang.Class({
         let languages = GLib.get_language_names();
         let files = languages.map(
             function(language) {
-                return Gio.File.new_for_path(Path.RESOURCE_DIR + '/getting-started/' + language +
+                return Gio.File.new_for_path(pkg.pkgdatadir + '/getting-started/' + language +
                     '/gnome-documents-getting-started.pdf');
             });
 
@@ -217,7 +202,7 @@ const Application = new Lang.Class({
     },
 
     _onActionQuit: function() {
-        this._mainWindow.window.destroy();
+        this._mainWindow.destroy();
     },
 
     _onActionAbout: function() {
@@ -226,7 +211,7 @@ const Application = new Lang.Class({
 
     _onActionHelp: function() {
         try {
-            Gtk.show_uri(this._mainWindow.window.get_screen(),
+            Gtk.show_uri(this._mainWindow.get_screen(),
                          'help:gnome-documents',
                          Gtk.get_current_event_time());
         } catch (e) {
@@ -251,13 +236,13 @@ const Application = new Lang.Class({
     _onActionOpenCurrent: function() {
         let doc = documentManager.getActiveItem();
         if (doc)
-            doc.open(this._mainWindow.window.get_screen(), Gtk.get_current_event_time());
+            doc.open(this._mainWindow.get_screen(), Gtk.get_current_event_time());
     },
 
     _onActionPrintCurrent: function() {
         let doc = documentManager.getActiveItem();
         if (doc)
-            doc.print(this._mainWindow.window);
+            doc.print(this._mainWindow);
     },
 
     _onActionToggle: function(action) {
@@ -271,7 +256,7 @@ const Application = new Lang.Class({
             return;
 
         let dialog = new Properties.PropertiesDialog(doc.id);
-        dialog.widget.connect('response', Lang.bind(this,
+        dialog.connect('response', Lang.bind(this,
             function(widget, response) {
                 widget.destroy();
             }));
@@ -289,7 +274,8 @@ const Application = new Lang.Class({
                     action = Gio.SimpleAction.new_stateful(actionEntry.name,
                         parameterType, actionEntry.state);
                 else
-                    action = new Gio.SimpleAction({ name: actionEntry.name });
+                    action = new Gio.SimpleAction({ name: actionEntry.name,
+                        parameter_type: parameterType });
 
                 if (actionEntry.create_hook)
                     actionEntry.create_hook.apply(this, [action]);
@@ -337,7 +323,7 @@ const Application = new Lang.Class({
 
     _initAppMenu: function() {
         let builder = new Gtk.Builder();
-        builder.add_from_resource('/org/gnome/documents/app-menu.ui');
+        builder.add_from_resource('/org/gnome/Documents/ui/app-menu.ui');
 
         let menu = builder.get_object('app-menu');
         this.set_app_menu(menu);
@@ -472,7 +458,7 @@ const Application = new Lang.Class({
         if (gtkSettings.gtk_theme_name == 'Adwaita') {
             if (cssProvider == null) {
                 cssProvider = new Gtk.CssProvider();
-                let file = Gio.File.new_for_uri("resource:///org/gnome/documents/Adwaita.css");
+                let file = Gio.File.new_for_uri("resource:///org/gnome/Documents/application.css");
                 cssProvider.load_from_file(file);
             }
 
@@ -490,9 +476,6 @@ const Application = new Lang.Class({
 
         EvDoc.init();
 
-        let resource = Gio.Resource.load(Path.RESOURCE_DIR + '/gnome-documents.gresource');
-        resource._register();
-
         application = this;
         if (!application.isBooks)
             settings = new Gio.Settings({ schema_id: 'org.gnome.documents' });
@@ -578,7 +561,8 @@ const Application = new Lang.Class({
               state: GLib.Variant.new('b', false),
               accel: 'F5' },
             { name: 'print-current', accel: '<Primary>p',
-              callback: this._onActionPrintCurrent },
+              callback: this._onActionPrintCurrent,
+              window_mode: WindowMode.WindowMode.PREVIEW },
             { name: 'search',
               callback: this._onActionToggle,
               state: GLib.Variant.new('b', false),
@@ -651,7 +635,7 @@ const Application = new Lang.Class({
         notificationManager = new Notifications.NotificationManager();
         this._connectActionsToMode();
         this._mainWindow = new MainWindow.MainWindow(this);
-        this._mainWindow.window.connect('destroy', Lang.bind(this, this._onWindowDestroy));
+        this._mainWindow.connect('destroy', Lang.bind(this, this._onWindowDestroy));
 
         try {
             this._extractPriority = TrackerExtractPriority();
@@ -683,7 +667,7 @@ const Application = new Lang.Class({
             modeController.setWindowMode(WindowMode.WindowMode.DOCUMENTS);
         }
 
-        this._mainWindow.window.present_with_time(this._activationTimestamp);
+        this._mainWindow.present_with_time(this._activationTimestamp);
         this._activationTimestamp = Gdk.CURRENT_TIME;
     },
 
@@ -775,7 +759,7 @@ const Application = new Lang.Class({
     getScaleFactor: function() {
         let scaleFactor = 1;
         if (this._mainWindow)
-            scaleFactor = this._mainWindow.window.get_scale_factor();
+            scaleFactor = this._mainWindow.get_scale_factor();
 
         return scaleFactor;
     },
@@ -783,7 +767,7 @@ const Application = new Lang.Class({
     getGdkWindow: function() {
         let window = null;
         if (this._mainWindow)
-            window = this._mainWindow.window.get_window();
+            window = this._mainWindow.get_window();
 
         return window;
     }
