@@ -19,9 +19,11 @@
  *
  */
 
+#include "config.h"
 #include "gd-utils.h"
 
 #include <gdk-pixbuf/gdk-pixbuf.h>
+#include <glib/gi18n.h>
 #include <string.h>
 #include <math.h>
 
@@ -384,3 +386,52 @@ gd_ev_view_find_changed (EvView *view,
                         ev_job_find_get_results (job),
                         page);
 }
+
+void
+gd_show_about_dialog (GtkWindow *parent,
+                      gboolean is_books)
+{
+  const char *artists[] = {
+    "Jakub Steiner <jimmac@gmail.com>",
+    NULL
+  };
+
+  const char *authors[] = {
+    "Cosimo Cecchi <cosimoc@gnome.org>",
+    "Florian Müllner <fmuellner@gnome.org>",
+    "William Jon McCann <william.jon.mccann@gmail.com>",
+    "Bastien Nocera <hadess@hadess.net>",
+    NULL
+  };
+
+  const char *program_name, *comments, *logo_icon_name, *website;
+
+  if(!is_books)
+    {
+      program_name = _("Documents");
+      comments = _("A document manager application");
+      logo_icon_name = "gnome-documents";
+      website = "https://wiki.gnome.org/Apps/Documents";
+    }
+  else
+    {
+      program_name = _("Books");
+      comments = _("An e-books manager application");
+      logo_icon_name = "gnome-books";
+      website = "https://wiki.gnome.org/Apps/Books";
+    }
+
+  gtk_show_about_dialog (parent,
+                         "artists", artists,
+                         "authors", authors,
+                         "translator-credits", _("translator-credits"),
+                         "program-name", program_name,
+                         "comments", comments,
+                         "logo-icon-name", logo_icon_name,
+                         "website", website,
+                         "copyright", "Copyright © 2011-2014 Red Hat, Inc.",
+                         "license-type", GTK_LICENSE_GPL_2_0,
+                         "version", PACKAGE_VERSION,
+                         "wrap-license", TRUE,
+                         NULL);
+}
