@@ -572,7 +572,7 @@ const PreviewView = new Lang.Class({
     },
 
     _updateNightMode: function() {
-        if (this._model) {
+        if (this._model && !Application.application.isBooks) {
             let nightMode = Application.settings.get_boolean('night-mode');
             this._model.set_inverted_colors(nightMode);
         }
@@ -687,7 +687,8 @@ const PreviewNavControls = new Lang.Class({
         this._motionId = 0;
         this._visibleInternal = true;
         this._updateVisibility();
-        this._queueAutoHide();
+        if (!this.bar_widget.hover)
+            this._queueAutoHide();
         return false;
     },
 
